@@ -10,7 +10,7 @@ Pulseaudio
 </name>
 
 <description>  
-advanced sound server system
+Advanced sound server system
 </description>
 
 <installable>
